[前][次][番号順一覧][スレッド一覧]

ruby-changes:3242

From: ko1@a...
Date: 27 Dec 2007 17:27:43 +0900
Subject: [ruby-changes:3242] akr - Ruby:r14735 (trunk): * parse.y, transcode_data.h, transcode.c: change "illegal" to

akr	2007-12-27 17:27:19 +0900 (Thu, 27 Dec 2007)

  New Revision: 14735

  Modified files:
    trunk/ChangeLog
    trunk/parse.y
    trunk/transcode.c
    trunk/transcode_data.h

  Log:
    * parse.y, transcode_data.h, transcode.c: change "illegal" to
      "invalid" in a context which doesn' t against a law.
    


  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi/trunk/transcode_data.h?r1=14735&r2=14734
  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi/trunk/parse.y?r1=14735&r2=14734
  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi/trunk/ChangeLog?r1=14735&r2=14734
  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi/trunk/transcode.c?r1=14735&r2=14734

Index: ChangeLog
===================================================================
--- ChangeLog	(revision 14734)
+++ ChangeLog	(revision 14735)
@@ -1,3 +1,8 @@
+Thu Dec 27 17:25:27 2007  Tanaka Akira  <akr@f...>
+
+	* parse.y, transcode_data.h, transcode.c: change "illegal" to
+	  "invalid" in a context which doesn' t against a law.
+
 Thu Dec 27 16:37:06 2007  Tanaka Akira  <akr@f...>
 
 	* re.c (rb_reg_s_union): show encodings in error message.
Index: parse.y
===================================================================
--- parse.y	(revision 14734)
+++ parse.y	(revision 14735)
@@ -6621,7 +6621,7 @@
 		    }
 		}
 		if (c > '7' && c <= '9') {
-		    yyerror("Illegal octal digit");
+		    yyerror("Invalid octal digit");
 		}
 		else if (c == '.' || c == 'e' || c == 'E') {
 		    tokadd('0');
Index: transcode_data.h
===================================================================
--- transcode_data.h	(revision 14734)
+++ transcode_data.h	(revision 14735)
@@ -32,7 +32,7 @@
 #define TWObt   (0x03)   /* two bytes payload */
 #define THREEbt (0x05)   /* three bytes payload */
 #define FOURbt  (0x06)   /* four bytes payload, UTF-8 only, macros start at getBT0 */
-#define ILLEGAL (PType 0x07)   /* illegal byte sequence */
+#define INVALID (PType 0x07)   /* invalid byte sequence */
 #define UNDEF   (PType 0x09)   /* legal but undefined */
 #define ZERObt  (PType 0x0A)   /* zero bytes of payload, i.e. remove */
 
Index: transcode.c
===================================================================
--- transcode.c	(revision 14734)
+++ transcode.c	(revision 14735)
@@ -183,14 +183,14 @@
 	    if (in_p >= in_stop) {
 		/* todo: deal with the case of backtracking */
 		/* todo: deal with incomplete input (streaming) */
-		goto illegal;
+		goto invalid;
 	    }
 	    next_byte = (unsigned char)*in_p++;
 	    if (from_utf8) {
 		if ((next_byte&0xC0) == 0x80)
 		    next_byte -= 0x80;
 		else
-		    goto illegal;
+		    goto invalid;
 	    }
 	    next_table = next_table->info[next_offset];
 	    goto follow_byte;
@@ -211,18 +211,18 @@
 	    *out_p++ = getBT2(next_info);
 	    *out_p++ = getBT3(next_info);
 	    continue;
-	  case ILLEGAL:
-	    goto illegal;
+	  case INVALID:
+	    goto invalid;
 	  case UNDEF:
 	    /* todo: add code for alternative behaviors */
-	    rb_raise(rb_eRuntimeError /*@@@change exception*/, "conversion undefined for byte sequence (maybe illegal byte sequence)");
+	    rb_raise(rb_eRuntimeError /*@@@change exception*/, "conversion undefined for byte sequence (maybe invalid byte sequence)");
 	    continue;
 	}
 	continue;
-      illegal:
-	/* deal with illegal byte sequence */
+      invalid:
+	/* deal with invalid byte sequence */
 	/* todo: add code for alternative behaviors */
-	rb_raise(rb_eRuntimeError /*change exception*/, "illegal byte sequence");
+	rb_raise(rb_eRuntimeError /*change exception*/, "invalid byte sequence");
 	continue;
     }
     /* cleanup */

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml

[前][次][番号順一覧][スレッド一覧]